#!/usr/bin/python

import hpp.corbaserver as hpc
from hpp_corbaserver.hpp import Configuration

cl = hpc.Client(['robot', 'obstacle', 'problem'])
robotClient = cl.robot
obstacleClient = cl.obstacle
problemClient = cl.problem

cfg = Configuration
cfg.trs = [0,0,0]
cfg.rot = [1,0,0,0,1,0,0,0,1]

#
# Create a robot with a free-flyer joint and a box.
#
robotClient.createJoint("Root", "freeflyer", cfg, [-10,10,-10,10,-10,10, 3.14159,-3.14159,3.14159,-3.14159,3.14159,-3.14159], True)
robotClient.createRobot("Car")
robotClient.setRobotRootJoint("Car", "Root")
robotClient.createBody("mainBody")
robotClient.attachBodyToJoint("Root", "mainBody")
robotClient.createBox("boxBody", 4.50, 1.82, 1.5)
cfg.trs = [1.35,0,0.85]
robotClient.addPolyToBody("mainBody", "boxBody",cfg)


# Add an extra dof for curvature
robotClient.createExtraDof("Curvature", 0, -0.5, 0.5)
robotClient.addExtraDofToRobot("Car", "Curvature")

robotClient.addHppProblem("Car", 0.05)

#
# Lock dofs of the robot to make it move in a plane.
#
# Tz
robotClient.setDofLocked(0, 3, 1, 0)
# Rx
robotClient.setDofLocked(0, 4, 1, 0)
# Ry
robotClient.setDofLocked(0, 5, 1, 0)

#
# Add obstacles
#

# Boundary
obstacleClient.createPolyhedron("boundary")
obstacleClient.addPoint("boundary", -10.2, -10.2, 0)
obstacleClient.addPoint("boundary", -10.2,  10.2, 0)
obstacleClient.addPoint("boundary",  10.2, -10.2, 0)
obstacleClient.addPoint("boundary",  10.2,  10.2, 0)
obstacleClient.addPoint("boundary", -10, -10, 1.0)
obstacleClient.addPoint("boundary", -10,  10, 1.0)
obstacleClient.addPoint("boundary",  10, -10, 1.0)
obstacleClient.addPoint("boundary",  10,  10, 1.0)
obstacleClient.addTriangle("boundary", 0, 1, 4)
obstacleClient.addTriangle("boundary", 5, 1, 4)
obstacleClient.addTriangle("boundary", 2, 3, 6)
obstacleClient.addTriangle("boundary", 7, 3, 6)
obstacleClient.addTriangle("boundary", 0, 2, 4)
obstacleClient.addTriangle("boundary", 6, 2, 4)
obstacleClient.addTriangle("boundary", 1, 3, 5)
obstacleClient.addTriangle("boundary", 7, 3, 5)

# passage
obstacleClient.createBox("obst1", 8.6, 0.2, 1.0)
obstacleClient.createBox("obst2", 8.6, 0.2, 1.0)

obstacleClient.addObstacle("boundary")
obstacleClient.addObstacle("obst1")
obstacleClient.addObstacle("obst2")

cfg.trs = [-5.7, 0, 0.5]
obstacleClient.moveObstacleConfig("obst1", cfg)
cfg.trs = [5.7, 0, 0.5]
obstacleClient.moveObstacleConfig("obst2", cfg)

#
# Instantiate problem
#

#init config
robotClient.setCurrentConfig(0, [0,-8,-8,0,0,0,0])
problemClient.setInitialConfig(0, [0,-8,-8,0,0,0,0])

#goal config
#robotClient.setCurrentConfig(0, [0,6,6,0,0,0,0])
problemClient.setGoalConfig(0, [0,6,6,0,0,0,0])

#
# Set flic steering method
#
problemClient.setSteeringMethod(0, "flic", False)

problemClient.setRoadmapbuilder(0, "IPP",True)
problemClient.setDistanceFunction(0, "flic", False)

problemClient.setPathOptimizer(0, "adaptiveShortcut", 100)

#problemClient.solve()
